# GPT

## Getting Started

### Installation

Kaar GPT is available as [`kaar-gpt`](https://pypi.org/project/kaar-gpt/) on PyPI:
```bash
pip install kaar-gpt
```

## Usage
```python
from gpt.openai import ChatCompletion, ChatCompletionRequest, ChatMessage
```
